==> siskin-0.123.0.tar.gz: siskin-0.123.0/siskin/mail.py <==
# coding: utf-8
# pylint: disable=F0401,C0111,W0232,E1101,R0904,E1103,C0301

# Copyright 2018 by Leipzig University Library, http://ub.uni-leipzig.de
#                   The Finc Authors, http://finc.info
#                   Martin Czygan, <martin.czygan@uni-leipzig.de>
#
# This file is part of some open source application.
#
# Some open source application is free software: you can redistribute
# it and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation, either
# version 3 of the License, or (at your option) any later version.
#
# Some open source application is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
#
# @license GPL-3.0+ <http://spdx.org/licenses/GPL-3.0+>
"""
Helper for sending mail.
"""

import datetime
import logging
import smtplib
import socket

from siskin.configuration import Config

config = Config.instance()
logger = logging.getLogger("siskin")

now = datetime.datetime.now()
day = now.strftime("%a")
month = now.strftime("%b")
date = now.strftime(day + ", %d " + month + " %Y %H:%M:%S +0100")


def send_mail(sender=None, date=date, tolist=None, subject=None, message=None, smtp=None, smtp_port=25, username=None, password=None, starttls=True):
    """
    Send out an email. Configure `smtp`, `default-sender` in `core` config
    section. A subject prefix is always prepended. The `tolist` parameter can
    be a single string or a list of strings.

    If username and password are both given, attempt a login (https://docs.python.org/3/library/smtplib.html#smtplib.SMTP.login).

    XXX: ATM no FROM: line, maybe add that.
    """
    if subject is None:
        subject = u"[automessage]"
    if smtp is None:
        smtp = config.get("core", "smtp")
    if smtp_port is None:
        smtp = config.get("core", "smtp-port")
    if sender is None:
        sender = config.get("core", "default-sender")

    if not all((sender, tolist, subject, smtp, message)):
        raise ValueError("missing sender, recipients, subject, message or smtp: %s" % locals())

    if not isinstance(tolist, list):
        tolist = [tolist]

    server = smtplib.SMTP(host=smtp, port=smtp_port)
    if starttls:
        server.starttls()
    if username and password:
        server.login(username, password)
    else:
        logger.debug("no username and password given, proceeding without login")
    msg = u'From: {}\nDate: {}\nSubject: {}\n\n{}'.format(sender, date, subject, message)
    server.sendmail(sender, tolist, msg)
    server.quit()

    logger.debug("sent mail (%d) to %s -- %s", len(message), ", ".join(tolist), subject)

==> siskin-1.3.1.tar.gz: siskin-1.3.1/siskin/mail.py <==
# coding: utf-8
# pylint: disable=F0401,C0111,W0232,E1101,R0904,E1103,C0301

# Copyright 2018 by Leipzig University Library, http://ub.uni-leipzig.de
#                   The Finc Authors, http://finc.info
#                   Martin Czygan, <martin.czygan@uni-leipzig.de>
#
# This file is part of some open source application.
#
# Some open source application is free software: you can redistribute
# it and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation, either
# version 3 of the License, or (at your option) any later version.
#
# Some open source application is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
#
# @license GPL-3.0+ <http://spdx.org/licenses/GPL-3.0+>
"""
Helper for sending mail.
"""

import datetime
import logging
import smtplib
import socket

from siskin.configuration import Config

config = Config.instance()
logger = logging.getLogger("siskin")

now = datetime.datetime.now()
day = now.strftime("%a")
month = now.strftime("%b")
date = now.strftime(day + ", %d " + month + " %Y %H:%M:%S +0100")


def send_mail(
    sender=None,
    date=date,
    tolist=None,
    subject=None,
    message=None,
    smtp=None,
    smtp_port=25,
    username=None,
    password=None,
    starttls=True,
):
    """
    Send out an email. Configure `smtp`, `default-sender` in `core` config
    section. A subject prefix is always prepended. The `tolist` parameter can
    be a single string or a list of strings.

    If username and password are both given, attempt a login (https://docs.python.org/3/library/smtplib.html#smtplib.SMTP.login).

    XXX: ATM no FROM: line, maybe add that.
    """
    if subject is None:
        subject = "[automessage]"
    if smtp is None:
        smtp = config.get("core", "smtp")
    if smtp_port is None:
        smtp = config.get("core", "smtp-port")
    if sender is None:
        sender = config.get("core", "default-sender")

    if not all((sender, tolist, subject, smtp, message)):
        raise ValueError(
            "missing sender, recipients, subject, message or smtp: %s" % locals()
        )

    if not isinstance(tolist, list):
        tolist = [tolist]

    server = smtplib.SMTP(host=smtp, port=smtp_port)
    if starttls:
        server.starttls()
    if username and password:
        server.login(username, password)
    else:
        logger.debug("no username and password given, proceeding without login")
    msg = "From: {}\nDate: {}\nSubject: {}\n\n{}".format(sender, date, subject, message)
    server.sendmail(sender, tolist, msg)
    server.quit()

    logger.debug("sent mail (%d) to %s -- %s", len(message), ", ".join(tolist), subject)
